@@ -1,105 +1,96 @@
-from __future__ import annotations
-
 import os
-import io
 import re
+import io
+import sys
 import yaml
-import click
+import argparse
 import operator
-import importlib.util
 
-from .configuration import Configuration
-from functools import reduce
-from typing import List
+from importlib.util import spec_from_file_location, module_from_spec
 from importlib.abc import Loader
 
-
-def printDefinition(definition: dict, indent: int = 0):
-    """ Helper method for printing a defintion in a nice way.
-
-    Args:
-        definition: The definition to display
-        indent: The number of spaces to use for indentation
-    """
-
-    # Create a buffer to hold the YAML output (the YAML library can only write to file)
-    buffer = io.StringIO()
-
-    # Dump the definition as YAML in the buffer and convert back to text
-    yaml.dump(definition, buffer)
-    definitionYAML = buffer.getvalue()
-
-    # Replace Python classes with their name (e.g. str, int, list, float, ...)
-    definitionYAML = re.sub(r"!!python\/name:builtins\.(\w+).+", r"\1", definitionYAML)
-
-    # Show the output
-    click.echo(definitionYAML)
+from typing import Any, List, Dict, Optional
+from functools import reduce
+from .configuration import Configuration
 
 
-def printDebug(context: click.Context, message: str):
-    if context.obj["DEBUG"]:
-        click.echo(click.style(f"🠊 {message}", fg="blue"))
+# Create the main parser
+parser = argparse.ArgumentParser(
+    description="""
+PyFiguration commandline tool
+
+Use this commandline tool to inspect scripts and have a look at the
+configuration options that the script provides. Furthermore you can
+inspect configuration files directly.
+""",
+    formatter_class=argparse.RawTextHelpFormatter,
+)
+
+# Create subparsers, command will be stored in dest command
+subprasers = parser.add_subparsers(dest="command", title="Commands")
+
+# Create a parser for the inspect command
+inspectParser = subprasers.add_parser(
+    "inspect",
+    help="Inspect configurations and scripts",
+    description="""Inspect configuration files, scripts or modules to
+        see which values are allowed, or to check if a provided
+        configuration file is valid for a specific script.""",
+)
+
+# Create nested commands for the inspect command
+inspectSubparsers = inspectParser.add_subparsers(
+    dest="inspect_type",
+    title="Commands",
+    description="""The type object you would like to inspect""",
+)
+
+# Add arguments for the configuration inspector
+configParser = inspectSubparsers.add_parser(
+    "config",
+    help="Inspect a configuration file to see if it is valid for a given script",
+    description="""This command will load the SCRIPT and look at the defintion. Then
+        it will load the CONFIG file and makes sure the CONFIG file is valid
+        for the provided SCRIPT. SCRIPT is the filename of the SCRIPT to inspect with PyFiguraton,
+        CONFIG file is the configuration file to inspect, against the SCRIPT."""
+)
+configParser.add_argument(
+    "-c", "--config", nargs="*", help="The configuration file to inspect",
+)
+configParser.add_argument(
+    "-s", "--script", help="The script against which to inspect the config",
+)
+
+# Add arguments for the script inspector
+scriptParser = inspectSubparsers.add_parser(
+    "script",
+    help="Inspect a script to see what configuration options are available",
+    description="""Provide a file or script to inspect it with PyFiguration. This command
+        will load the script from file and inspect the PyFiguration decorators
+        to find out what the configuration options are. Then, it will display all
+        the option as the output of this command. SCRIPT is the filename of the
+        script to inspect with PyFiguraton"""
+)
+scriptParser.add_argument(
+    "-s", "--script", help="The script against which to inspect the config",
+)
+
+# # Add arguments for the module inspector
+# moduleParser = inspectSubparsers.add_parser(
+#     "module",
+#     help="Inspect a module to see what configuration options are available",
+#     description="""Provide a file or script to inspect it with PyFiguration. This command
+#         will load the script from file and inspect the PyFiguration decorators
+#         to find out what the configuration options are. Then, it will display all
+#         the option as the output of this command. SCRIPT is the filename of the
+#         script to inspect with PyFiguraton"""
+# )
+# moduleParser.add_argument(
+#     "-s", "--script", help="The script against which to inspect the config",
+# )
 
 
-@click.group()
-@click.option("--debug/--no-debug", default=False)
-@click.pass_context
-def cli(context: click.Context, debug: bool = False):
-    """ PyFiguration commandline tool
-
-    Use this commandline tool to inspect scripts and have a look at the
-    configuration options that the script provides. Furthermore you can
-    inspect configuration files directly.
-    """
-
-    # Create the context for all commands
-    context.ensure_object(dict)
-
-    # Set the debug mode
-    context.obj["DEBUG"] = debug
-
-    # Show info if we're in debug mode
-    printDebug(context, "Debug mode is enabled")
-
-
-@cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True))
-@click.pass_context
-@click.argument("module", type=click.Path(exists=True))
-def module(context: click.Context, module: str):
-    """ Inspect a module
-
-    Provide a file or module to inspect it with PyFiguration. This command
-    will load the script from file and inspect the PyFiguration decorators
-    to find out what the configuration options are. Then, it will display all
-    the option as the output of this command.
-
-    MODULE is the filename of the module to inspect with PyFiguraton
-    """
-
-    # Extract the module name from the file
-    printDebug(context, f"Start inspection of file '{module}'")
-    moduleName = os.path.splitext(os.path.split(module)[-1])[0]
-
-    # Load the module from file
-    spec = importlib.util.spec_from_file_location(moduleName, module)
-    importedModule = importlib.util.module_from_spec(spec)
-    if isinstance(spec.loader, Loader):
-        spec.loader.exec_module(importedModule)
-
-    # Get the configuration from the module
-    conf = getattr(importedModule, "conf")
-    printDebug(context, f"Loaded the configuration from the module")
-
-    click.echo(
-        f"The following options can be used in a configuration file for the module '{module}':"
-    )
-    printDefinition(conf.configuration.getDefinition())
-
-
-@cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True))
-@click.pass_context
-@click.argument("module", type=click.Path(exists=True))
-def config(context: click.Context, module: str):
+def inspectConfig(script: str, *args, **kwargs):
     """ Inspect a configuration file
 
     This command will load the MODULE and look at the defintion. Then
@@ -111,25 +102,25 @@ def config(context: click.Context, module: str):
     """
 
     # Extract the module name from the file
-    printDebug(context, f"Start inspection of file '{module}'")
-    moduleName = os.path.splitext(os.path.split(module)[-1])[0]
+    scriptName = os.path.splitext(os.path.split(script)[-1])[0]
 
     # Load the module from file
     os.environ["CLI"] = "TRUE"
-    spec = importlib.util.spec_from_file_location(moduleName, module)
-    importedModule = importlib.util.module_from_spec(spec)
+    spec = spec_from_file_location(scriptName, script)
+    importedModule = module_from_spec(spec)
     if isinstance(spec.loader, Loader):
         spec.loader.exec_module(importedModule)
 
     # Get the configuration from the module
     conf = getattr(importedModule, "conf")
-    printDebug(context, f"Loaded the configuration from the module")
 
     # Set the configfile explicitly on the configuration of the module
     conf.set_configuration()
 
     # Access all keys to check if they're valid
-    def checkConfig(configuration: Configuration, definition: dict, parents: List[str] = []):
+    def checkConfig(
+        configuration: Configuration, definition: dict, parents: List[str] = []
+    ):
         """
         """
         errors: List[str] = []
@@ -220,10 +211,98 @@ def config(context: click.Context, module: str):
 
     # Show the found warnings and errors
     if len(errors) > 0:
-        click.echo(click.style("--------\n Errors \n--------"))
+        print("--------\n Errors \n--------")
     for error in errors:
-        click.echo(click.style(f"   ✗ {error}", fg="red"))
+        print(f"   ✗ {error}")
     if len(warnings) > 0:
-        click.echo(click.style("----------\n Warnings \n----------"))
+        print("----------\n Warnings \n----------")
     for warning in warnings:
-        click.echo(click.style(f"   ! {warning}", fg="yellow"))
+        print(f"   ! {warning}")
+
+
+def inspectScript(script: str, *args, **kwargs):
+    """ Inspect a module
+
+    Provide a file or module to inspect it with PyFiguration. This command
+    will load the script from file and inspect the PyFiguration decorators
+    to find out what the configuration options are. Then, it will display all
+    the option as the output of this command.
+
+    MODULE is the filename of the module to inspect with PyFiguraton
+    """
+
+    # Extract the module name from the file
+    scriptName = os.path.splitext(os.path.split(script)[-1])[0]
+
+    # Load the module from file
+    spec = spec_from_file_location(scriptName, script)
+    importedModule = module_from_spec(spec)
+    if isinstance(spec.loader, Loader):
+        spec.loader.exec_module(importedModule)
+
+    # Get the configuration from the module
+    conf = getattr(importedModule, "conf")
+
+    print(
+        f"The following options can be used in a configuration file for the module '{script}':"
+    )
+    printDefinition(conf.configuration.getDefinition())
+
+
+def printDefinition(definition: Dict[str, Any], indent: int = 0):
+    """ Helper method for printing a defintion in a nice way.
+
+    Args:
+        definition (dict): The definition to display
+        indent (int, optional): The number of spaces to use for indentation
+    """
+
+    # Create a buffer to hold the YAML output (the YAML library can only write to file)
+    buffer = io.StringIO()
+
+    # Dump the definition as YAML in the buffer and convert back to text
+    yaml.dump(definition, buffer)
+    definitionYAML = buffer.getvalue()
+
+    # Replace Python classes with their name (e.g. str, int, list, float, ...)
+    definitionYAML = re.sub(r"!!python\/name:builtins\.(\w+).+", r"\1", definitionYAML)
+
+    # Show the output
+    print(definitionYAML)
+
+
+def showHelp(exitCode: int = 1):
+    """ Show the help text from the argument parser.
+
+    Args:
+        exitCode (int, optional): The exit code to return when shutting down. Defaults to 1.
+    """
+
+    parser.print_help(sys.stderr)
+    sys.exit(1)
+
+
+def cli(args: Optional[List[str]] = None):
+    """ Parse the arguments from the command line and
+    take the appropriate action.
+    """
+
+    # Parse the input arguments
+    args = vars(parser.parse_known_args(args)[0])
+
+    # Execute the selected action
+    actions[args.get("command", None)][args.get("inspect_type", None)](**args)
+
+
+actions = {
+    "inspect": {
+        "config": inspectConfig,
+        "script": inspectScript,
+        "module": inspectScript,
+    },
+    None: showHelp,
+}
+
+
+if __name__ == "__main__":
+    cli(sys.argv[1:])
